@@ -37,6 +37,7 @@
 #include <callback_gal.h>
 #include <eda_text.h>         // for EDA_TEXT, TEXT_EFFECTS, GR_TEXT_VJUSTIF...
 #include <gal/color4d.h>      // for COLOR4D, COLOR4D::BLACK
+#include <font/glyph.h>
 #include <gr_text.h>
 #include <string_utils.h>     // for UnescapeString
 #include <math/util.h>        // for KiROUND
@@ -90,6 +91,7 @@ GR_TEXT_V_ALIGN_T EDA_TEXT::MapVertJustify( int aVertJustify )
 EDA_TEXT::EDA_TEXT( const EDA_IU_SCALE& aIuScale, const wxString& aText ) :
         m_text( aText ),
         m_IuScale( aIuScale ),
+        m_render_cache_font( nullptr ),
         m_bounding_box_cache_valid( false ),
         m_bounding_box_cache_line( -1 ),
         m_bounding_box_cache_inverted( false )
@@ -110,15 +112,19 @@ EDA_TEXT::EDA_TEXT( const EDA_TEXT& aText ) :
     m_attributes = aText.m_attributes;
     m_pos = aText.m_pos;
 
+    m_render_cache_font = aText.m_render_cache_font;
     m_render_cache_text = aText.m_render_cache_text;
     m_render_cache_angle = aText.m_render_cache_angle;
+    m_render_cache_offset = aText.m_render_cache_offset;
 
     m_render_cache.clear();
 
     for( const std::unique_ptr<KIFONT::GLYPH>& glyph : aText.m_render_cache )
     {
-        KIFONT::OUTLINE_GLYPH* outline_glyph = static_cast<KIFONT::OUTLINE_GLYPH*>( glyph.get() );
-        m_render_cache.emplace_back( std::make_unique<KIFONT::OUTLINE_GLYPH>( *outline_glyph ) );
+        if( KIFONT::OUTLINE_GLYPH* outline = dynamic_cast<KIFONT::OUTLINE_GLYPH*>( glyph.get() ) )
+            m_render_cache.emplace_back( std::make_unique<KIFONT::OUTLINE_GLYPH>( *outline ) );
+        else if( KIFONT::STROKE_GLYPH* stroke = dynamic_cast<KIFONT::STROKE_GLYPH*>( glyph.get() ) )
+            m_render_cache.emplace_back( std::make_unique<KIFONT::STROKE_GLYPH>( *stroke ) );
     }
 
     m_bounding_box_cache_valid = aText.m_bounding_box_cache_valid;
@@ -142,15 +148,19 @@ EDA_TEXT& EDA_TEXT::operator=( const EDA_TEXT& aText )
     m_attributes = aText.m_attributes;
     m_pos = aText.m_pos;
 
+    m_render_cache_font = aText.m_render_cache_font;
     m_render_cache_text = aText.m_render_cache_text;
     m_render_cache_angle = aText.m_render_cache_angle;
+    m_render_cache_offset = aText.m_render_cache_offset;
 
     m_render_cache.clear();
 
     for( const std::unique_ptr<KIFONT::GLYPH>& glyph : aText.m_render_cache )
     {
-        KIFONT::OUTLINE_GLYPH* outline_glyph = static_cast<KIFONT::OUTLINE_GLYPH*>( glyph.get() );
-        m_render_cache.emplace_back( std::make_unique<KIFONT::OUTLINE_GLYPH>( *outline_glyph ) );
+        if( KIFONT::OUTLINE_GLYPH* outline = dynamic_cast<KIFONT::OUTLINE_GLYPH*>( glyph.get() ) )
+            m_render_cache.emplace_back( std::make_unique<KIFONT::OUTLINE_GLYPH>( *outline ) );
+        else if( KIFONT::STROKE_GLYPH* stroke = dynamic_cast<KIFONT::STROKE_GLYPH*>( glyph.get() ) )
+            m_render_cache.emplace_back( std::make_unique<KIFONT::STROKE_GLYPH>( *stroke ) );
     }
 
     m_bounding_box_cache_valid = aText.m_bounding_box_cache_valid;
@@ -388,10 +398,18 @@ void EDA_TEXT::SetTextY( int aY )
 
 void EDA_TEXT::Offset( const VECTOR2I& aOffset )
 {
+    if( aOffset.x == 0 && aOffset.y == 0 )
+        return;
+
     m_pos += aOffset;
 
     for( std::unique_ptr<KIFONT::GLYPH>& glyph : m_render_cache )
-        static_cast<KIFONT::OUTLINE_GLYPH*>( glyph.get() )->Move( aOffset );
+    {
+        if( KIFONT::OUTLINE_GLYPH* outline = dynamic_cast<KIFONT::OUTLINE_GLYPH*>( glyph.get() ) )
+            outline->Move( aOffset );
+        else if( KIFONT::STROKE_GLYPH* stroke = dynamic_cast<KIFONT::STROKE_GLYPH*>( glyph.get() ) )
+            glyph = stroke->Transform( { 1.0, 1.0 }, aOffset, 0, ANGLE_0, false, { 0, 0 } );
+    }
 
     m_bounding_box_cache_valid = false;
 }
@@ -451,23 +469,26 @@ std::vector<std::unique_ptr<KIFONT::GLYPH>>*
 EDA_TEXT::GetRenderCache( const KIFONT::FONT* aFont, const wxString& forResolvedText,
                           const VECTOR2I& aOffset ) const
 {
-    if( getDrawFont()->IsOutline() )
+    if( aFont->IsOutline() )
     {
         EDA_ANGLE resolvedAngle = GetDrawRotation();
 
         if( m_render_cache.empty()
+                || m_render_cache_font != aFont
                 || m_render_cache_text != forResolvedText
                 || m_render_cache_angle != resolvedAngle
                 || m_render_cache_offset != aOffset )
         {
             m_render_cache.clear();
 
-            KIFONT::OUTLINE_FONT* font = static_cast<KIFONT::OUTLINE_FONT*>( getDrawFont() );
-            TEXT_ATTRIBUTES       attrs = GetAttributes();
+            const KIFONT::OUTLINE_FONT* font = static_cast<const KIFONT::OUTLINE_FONT*>( aFont );
+            TEXT_ATTRIBUTES             attrs = GetAttributes();
 
             attrs.m_Angle = resolvedAngle;
 
-            font->GetLinesAsGlyphs( &m_render_cache, GetShownText(), GetDrawPos() + aOffset, attrs );
+            font->GetLinesAsGlyphs( &m_render_cache, forResolvedText, GetDrawPos() + aOffset,
+                                    attrs );
+            m_render_cache_font = aFont;
             m_render_cache_angle = resolvedAngle;
             m_render_cache_text = forResolvedText;
             m_render_cache_offset = aOffset;
@@ -514,7 +535,7 @@ BOX2I EDA_TEXT::GetTextBox( int aLine, bool aInvertY ) const
 
     BOX2I          bbox;
     wxArrayString  strings;
-    wxString       text = GetShownText();
+    wxString       text = GetShownText( true );
     int            thickness = GetEffectiveTextPenWidth();
 
     if( IsMultilineAllowed() )
@@ -542,12 +563,16 @@ BOX2I EDA_TEXT::GetTextBox( int aLine, bool aInvertY ) const
     // bounding box will be moved later according to the actual text options
     wxSize   textsize = wxSize( extents.x, extents.y );
     VECTOR2I pos = drawPos;
+    int      fudgeFactor = extents.y * 0.17;
+
+    if( font->IsStroke() )
+        textsize.y += fudgeFactor;
 
     if( IsMultilineAllowed() && aLine > 0 && aLine < (int) strings.GetCount() )
         pos.y -= KiROUND( aLine * font->GetInterline( fontSize.y ) );
 
     if( text.Contains( wxT( "~{" ) ) )
-        overbarOffset = extents.y / 14;
+        overbarOffset = extents.y / 6;
 
     if( aInvertY )
         pos.y = -pos.y;
@@ -555,7 +580,7 @@ BOX2I EDA_TEXT::GetTextBox( int aLine, bool aInvertY ) const
     bbox.SetOrigin( pos );
 
     // for multiline texts and aLine < 0, merge all rectangles (aLine == -1 signals all lines)
-    if( IsMultilineAllowed() && aLine < 0 && strings.GetCount() )
+    if( IsMultilineAllowed() && aLine < 0 && strings.GetCount() > 1 )
     {
         for( unsigned ii = 1; ii < strings.GetCount(); ii++ )
         {
@@ -569,6 +594,8 @@ BOX2I EDA_TEXT::GetTextBox( int aLine, bool aInvertY ) const
         textsize.y += KiROUND( ( strings.GetCount() - 1 ) * font->GetInterline( fontSize.y ) );
     }
 
+    textsize.y += overbarOffset;
+
     bbox.SetSize( textsize );
 
     /*
@@ -597,14 +624,16 @@ BOX2I EDA_TEXT::GetTextBox( int aLine, bool aInvertY ) const
     switch( GetVertJustify() )
     {
     case GR_TEXT_V_ALIGN_TOP:
+        bbox.Offset( 0, -fudgeFactor );
         break;
 
     case GR_TEXT_V_ALIGN_CENTER:
-        bbox.SetY( bbox.GetY() - ( bbox.GetHeight() + overbarOffset ) / 2 );
+        bbox.SetY( bbox.GetY() - bbox.GetHeight() / 2 );
         break;
 
     case GR_TEXT_V_ALIGN_BOTTOM:
-        bbox.SetY( bbox.GetY() - ( bbox.GetHeight() + overbarOffset ) );
+        bbox.SetY( bbox.GetY() - bbox.GetHeight() );
+        bbox.Offset( 0, fudgeFactor );
         break;
     }
 
@@ -652,7 +681,7 @@ void EDA_TEXT::Print( const RENDER_SETTINGS* aSettings, const VECTOR2I& aOffset,
     {
         std::vector<VECTOR2I> positions;
         wxArrayString  strings;
-        wxStringSplit( GetShownText(), strings, '\n' );
+        wxStringSplit( GetShownText( true ), strings, '\n' );
 
         positions.reserve( strings.Count() );
 
@@ -663,7 +692,8 @@ void EDA_TEXT::Print( const RENDER_SETTINGS* aSettings, const VECTOR2I& aOffset,
     }
     else
     {
-        printOneLineOfText( aSettings, aOffset, aColor, aFillMode, GetShownText(), GetDrawPos() );
+        printOneLineOfText( aSettings, aOffset, aColor, aFillMode, GetShownText( true ),
+                            GetDrawPos() );
     }
 }
 
@@ -851,18 +881,33 @@ void EDA_TEXT::Format( OUTPUTFORMATTER* aFormatter, int aNestLevel, int aControl
 
 
 std::shared_ptr<SHAPE_COMPOUND> EDA_TEXT::GetEffectiveTextShape( bool aTriangulate,
-                                                                 bool aUseTextRotation ) const
+                                                                 const BOX2I& aBBox,
+                                                                 const EDA_ANGLE& aAngle ) const
 {
     std::shared_ptr<SHAPE_COMPOUND> shape = std::make_shared<SHAPE_COMPOUND>();
     KIGFX::GAL_DISPLAY_OPTIONS      empty_opts;
     KIFONT::FONT*                   font = getDrawFont();
     int                             penWidth = GetEffectiveTextPenWidth();
+    wxString                        shownText( GetShownText( true ) );
+    VECTOR2I                        drawPos = GetDrawPos();
     TEXT_ATTRIBUTES                 attrs = GetAttributes();
 
-    if( aUseTextRotation )
-        attrs.m_Angle = GetDrawRotation();
+    std::vector<std::unique_ptr<KIFONT::GLYPH>>* cache = nullptr;
+
+    if( aBBox.GetWidth() )
+    {
+        drawPos = aBBox.GetCenter();
+        attrs.m_Halign = GR_TEXT_H_ALIGN_CENTER;
+        attrs.m_Valign = GR_TEXT_V_ALIGN_CENTER;
+        attrs.m_Angle = aAngle;
+    }
     else
-        attrs.m_Angle = ANGLE_0;
+    {
+        attrs.m_Angle = GetDrawRotation();
+
+        if( font->IsOutline() )
+            cache = GetRenderCache( font, shownText, VECTOR2I() );
+    }
 
     if( aTriangulate )
     {
@@ -884,7 +929,10 @@ std::shared_ptr<SHAPE_COMPOUND> EDA_TEXT::GetEffectiveTextShape( bool aTriangula
                     shape->AddShape( triShape );
                 } );
 
-        font->Draw( &callback_gal, GetShownText(), GetDrawPos(), attrs );
+        if( cache )
+            callback_gal.DrawGlyphs( *cache );
+        else
+            font->Draw( &callback_gal, shownText, drawPos, attrs );
     }
     else
     {
@@ -901,7 +949,10 @@ std::shared_ptr<SHAPE_COMPOUND> EDA_TEXT::GetEffectiveTextShape( bool aTriangula
                     shape->AddShape( aPoly.Clone() );
                 } );
 
-        font->Draw( &callback_gal, GetShownText(), GetDrawPos(), attrs );
+        if( cache )
+            callback_gal.DrawGlyphs( *cache );
+        else
+            font->Draw( &callback_gal, shownText, drawPos, attrs );
     }
 
     return shape;
@@ -942,41 +993,6 @@ int EDA_TEXT::Compare( const EDA_TEXT* aOther ) const
 }
 
 
-void EDA_TEXT::TransformBoundingBoxToPolygon( SHAPE_POLY_SET* aBuffer, int aClearance ) const
-{
-    if( GetText().Length() == 0 )
-        return;
-
-    VECTOR2I corners[4];    // Buffer of polygon corners
-    BOX2I    rect = GetTextBox();
-
-    // TrueType bounding boxes aren't guaranteed to include all descenders, diacriticals, etc.
-    // Since we use this for zone knockouts and DRC, we need something more accurate.
-    if( getDrawFont()->IsOutline() )
-        rect = GetEffectiveTextShape( false, false )->BBox();
-
-    rect.Inflate( aClearance );
-
-    corners[0].x = rect.GetOrigin().x;
-    corners[0].y = rect.GetOrigin().y;
-    corners[1].y = corners[0].y;
-    corners[1].x = rect.GetRight();
-    corners[2].x = corners[1].x;
-    corners[2].y = rect.GetBottom();
-    corners[3].y = corners[2].y;
-    corners[3].x = corners[0].x;
-
-    aBuffer->NewOutline();
-
-    for( VECTOR2I& corner : corners )
-    {
-        RotatePoint( corner, GetDrawPos(), GetDrawRotation() );
-
-        aBuffer->Append( corner.x, corner.y );
-    }
-}
-
-
 bool EDA_TEXT::ValidateHyperlink( const wxString& aURL )
 {
     if( aURL.IsEmpty() || IsGotoPageHref( aURL ) )
