@@ -116,7 +116,11 @@ SYMBOL_EDIT_FRAME::SYMBOL_EDIT_FRAME( KIWAY* aKiway, wxWindow* aParent ) :
     wxIcon icon;
     wxIconBundle icon_bundle;
 
-    icon.CopyFromBitmap( KiBitmap( BITMAPS::icon_libedit ) );
+    icon.CopyFromBitmap( KiBitmap( BITMAPS::icon_libedit, 48 ) );
+    icon_bundle.AddIcon( icon );
+    icon.CopyFromBitmap( KiBitmap( BITMAPS::icon_libedit, 256 ) );
+    icon_bundle.AddIcon( icon );
+    icon.CopyFromBitmap( KiBitmap( BITMAPS::icon_libedit, 128 ) );
     icon_bundle.AddIcon( icon );
     icon.CopyFromBitmap( KiBitmap( BITMAPS::icon_libedit_32 ) );
     icon_bundle.AddIcon( icon );
@@ -170,7 +174,7 @@ SYMBOL_EDIT_FRAME::SYMBOL_EDIT_FRAME( KIWAY* aKiway, wxWindow* aParent ) :
     ReCreateVToolbar();
     ReCreateOptToolbar();
 
-    updateTitle();
+    UpdateTitle();
     UpdateSymbolMsgPanelInfo();
     RebuildSymbolUnitsList();
 
@@ -558,7 +562,7 @@ bool SYMBOL_EDIT_FRAME::CanCloseSymbolFromSchematic( bool doClose )
     if( doClose )
     {
         SetCurSymbol( nullptr, false );
-        updateTitle();
+        UpdateTitle();
     }
 
     return true;
@@ -781,7 +785,7 @@ void SYMBOL_EDIT_FRAME::SetCurSymbol( LIB_SYMBOL* aSymbol, bool aUpdateZoom )
                                                        wxEmptyString );
 
         button->Bind( wxEVT_COMMAND_HYPERLINK, std::function<void( wxHyperlinkEvent& aEvent )>(
-                [&]( wxHyperlinkEvent& aEvent )
+                [=]( wxHyperlinkEvent& aEvent )
                 {
                     InvokeSchEditSymbolLibTable( &Kiway(), this );
                 } ) );
@@ -794,7 +798,14 @@ void SYMBOL_EDIT_FRAME::SetCurSymbol( LIB_SYMBOL* aSymbol, bool aUpdateZoom )
     }
     else if( IsSymbolAlias() )
     {
-        wxString parentSymbolName = m_symbol->GetParent().lock()->GetName();
+        std::shared_ptr<LIB_SYMBOL> parent = m_symbol->GetParent().lock();
+
+        // Don't assume the parent symbol shared pointer is still valid.
+        wxCHECK( parent, /* void */ );
+
+        wxString parentSymbolName = parent->GetName();
+        int      unit = GetUnit();
+        int      convert = GetConvert();
         wxString msg;
         wxString link;
 
@@ -806,10 +817,9 @@ void SYMBOL_EDIT_FRAME::SetCurSymbol( LIB_SYMBOL* aSymbol, bool aUpdateZoom )
 
         wxHyperlinkCtrl* button = new wxHyperlinkCtrl( infobar, wxID_ANY, link, wxEmptyString );
         button->Bind( wxEVT_COMMAND_HYPERLINK, std::function<void( wxHyperlinkEvent& aEvent )>(
-                [&]( wxHyperlinkEvent& aEvent )
+                [=]( wxHyperlinkEvent& aEvent )
                 {
-                    LoadSymbolFromCurrentLib( m_symbol->GetParent().lock()->GetName(),
-                                              GetUnit(), GetConvert() );
+                    LoadSymbolFromCurrentLib( parentSymbolName, unit, convert );
                 } ) );
 
         infobar->RemoveAllButtons();
@@ -843,7 +853,7 @@ void SYMBOL_EDIT_FRAME::OnModify()
     m_treePane->GetLibTree()->RefreshLibTree();
 
     if( !GetTitle().StartsWith( "*" ) )
-        updateTitle();
+        UpdateTitle();
 }
 
 
@@ -1218,7 +1228,7 @@ void SYMBOL_EDIT_FRAME::ShowChangedLanguage()
         GetCanvas()->Refresh();
     }
 
-    updateTitle();
+    UpdateTitle();
 }
 
 
@@ -1512,7 +1522,7 @@ void SYMBOL_EDIT_FRAME::LoadSymbolFromSchematic( SCH_SYMBOL* aSymbol )
         OnToggleSymbolTree( evt );
     }
 
-    updateTitle();
+    UpdateTitle();
     RebuildSymbolUnitsList();
     SetShowDeMorgan( GetCurSymbol()->HasConversion() );
     UpdateSymbolMsgPanelInfo();
