@@ -212,17 +212,16 @@ void PCM_TASK_MANAGER::installDownloadedPackage( const PCM_PACKAGE& aPackage,
         if( extract( aFilePath.GetFullPath(), aPackage.identifier, true ) )
         {
             m_pcm->MarkInstalled( aPackage, pkgver->version, aRepositoryId );
-            // TODO register libraries.
         }
         else
         {
             // Cleanup possibly partially extracted package
             deletePackageDirectories( aPackage.identifier );
         }
-    }
 
-    if( aPackage.type == PCM_PACKAGE_TYPE::PT_COLORTHEME )
-        m_color_themes_changed.store( true );
+        std::unique_lock lock( m_changed_package_types_guard );
+        m_changed_package_types.insert( aPackage.type );
+    }
 
     m_reporter->PCMReport(
             wxString::Format( _( "Removing downloaded archive '%s'." ), aFilePath.GetFullName() ),
@@ -372,6 +371,7 @@ void PCM_TASK_MANAGER::InstallFromFile( wxWindow* aParent, const wxString& aFile
     }
 
     PCM_PACKAGE package = metadata.get<PCM_PACKAGE>();
+    PLUGIN_CONTENT_MANAGER::PreparePackage( package );
 
     if( package.versions.size() != 1 )
     {
@@ -379,6 +379,15 @@ void PCM_TASK_MANAGER::InstallFromFile( wxWindow* aParent, const wxString& aFile
         return;
     }
 
+    if( !package.versions[0].compatible
+        && wxMessageBox( _( "This package version is incompatible with your kicad version or "
+                            "platform. Are you sure you want to install it anyway?" ),
+                         _( "Install package" ), wxICON_EXCLAMATION | wxYES_NO, aParent )
+                   == wxNO )
+    {
+        return;
+    }
+
     bool isUpdate = false;
     // wxRegEx is not CopyConstructible hence the weird choice of forward_list
     std::forward_list<wxRegEx>                keep_on_update;
@@ -431,7 +440,8 @@ void PCM_TASK_MANAGER::InstallFromFile( wxWindow* aParent, const wxString& aFile
 
     aParent->Raise();
 
-    m_color_themes_changed.store( package.type == PCM_PACKAGE_TYPE::PT_COLORTHEME );
+    std::unique_lock lock( m_changed_package_types_guard );
+    m_changed_package_types.insert( package.type );
 }
 
 
@@ -560,8 +570,8 @@ void PCM_TASK_MANAGER::Uninstall( const PCM_PACKAGE& aPackage )
 
         m_pcm->MarkUninstalled( aPackage );
 
-        if( aPackage.type == PCM_PACKAGE_TYPE::PT_COLORTHEME )
-            m_color_themes_changed.store( true );
+        std::unique_lock lock( m_changed_package_types_guard );
+        m_changed_package_types.insert( aPackage.type );
 
         m_reporter->PCMReport(
                 wxString::Format( _( "Package %s uninstalled" ), aPackage.identifier ),
@@ -589,8 +599,6 @@ void PCM_TASK_MANAGER::RunQueue( wxWindow* aParent )
     std::condition_variable condvar;
     bool                    download_complete = false;
 
-    m_color_themes_changed.store( false );
-
     std::thread download_thread(
             [&]()
             {
@@ -642,17 +650,14 @@ void PCM_TASK_MANAGER::RunQueue( wxWindow* aParent )
             } );
 
     m_reporter->KeepRefreshing( true );
+
+    download_thread.join();
+    install_thread.join();
+
+    // Destroy the reporter only after the threads joined
+    // Incase the reporter terminated due to cancellation
     m_reporter->Destroy();
     m_reporter.reset();
 
     aParent->Raise();
-
-    download_thread.join();
-    install_thread.join();
 }
-
-
-bool PCM_TASK_MANAGER::ColorSettingsChanged() const
-{
-    return m_color_themes_changed.load();
-}
\ No newline at end of file
