@@ -419,7 +419,7 @@ bool BOARD_NETLIST_UPDATER::updateComponentPadConnections( FOOTPRINT* aFootprint
     // Create a copy only if the footprint has not been added during this update
     FOOTPRINT* copy = nullptr;
 
-    if( !m_commit.GetStatus( aFootprint ) )  
+    if( !m_commit.GetStatus( aFootprint ) )
     {
         copy = static_cast<FOOTPRINT*>( aFootprint->Clone() );
         copy->SetParentGroup( nullptr );
@@ -487,6 +487,7 @@ bool BOARD_NETLIST_UPDATER::updateComponentPadConnections( FOOTPRINT* aFootprint
                             aFootprint->GetReference(),
                             pad->GetNumber() );
                 m_reporter->Report( msg, RPT_SEVERITY_WARNING);
+                ++m_warningCount;
             }
 
             if( !m_isDryRun )
@@ -1053,7 +1054,10 @@ bool BOARD_NETLIST_UPDATER::UpdateNetlist( NETLIST& aNetlist )
         m_commit.Push( _( "Update netlist" ), m_newFootprintsCount ? ZONE_FILL_OP  : 0 );
 
         m_board->SynchronizeNetsAndNetClasses( true );
-        m_frame->SaveProjectSettings();
+
+        // Although m_commit will probably also set this, it's not guaranteed, and we need to make
+        // sure any modification to netclasses gets persisted to project settings through a save.
+        m_frame->OnModify();
     }
 
     if( m_isDryRun )
